@@ -19,10 +19,10 @@ use strict;
 use warnings;
 
 use Spreadsheet::ParseExcel::Utility qw(ExcelFmt);
-our $VERSION = '0.61';
+our $VERSION = '0.62';
 
 my %hFmtDefault = (
-    0x00 => '@',
+    0x00 => 'General',
     0x01 => '0',
     0x02 => '0.00',
     0x03 => '#,##0',
